@@ -23,7 +23,6 @@ from . import gis_import_error_message
 
 try:
     import rioxarray
-    from clisops.core import subset
 except (ImportError, ModuleNotFoundError) as e:
     msg = gis_import_error_message.format(Path(__file__).stem)
     raise ImportError(msg) from e
@@ -321,9 +320,18 @@ def get_subsetted_forecast(region_coll, ds, times, is_caspar):
     lat_min = region_coll.bounds[1]
     lat_max = region_coll.bounds[3]
 
+    # Add a very simple lon wraparound if data suggests for it
+    if ((ds.lon.min() >= 0) and (ds.lon.max() <= 360)) and (lon_max < 0):
+        lon_min += 360
+        lon_max += 360
+
     # Subset the data to the desired location (bounding box) and times
-    ds = subset.subset_bbox(
-        ds, lon_bnds=[lon_min, lon_max], lat_bnds=[lat_min, lat_max]
+    ds = ds.where(
+        (ds.lon <= lon_max)
+        & (ds.lon >= lon_min)
+        & (ds.lat <= lat_max)
+        & (ds.lat >= lat_min),
+        drop=True,
     ).sel(time=times)
 
     # Rioxarray requires CRS definitions for variables
